diff --git a/examples/DOM/DOMWriter.cpp b/examples/DOM/DOMWriter.cpp
index 6dddaf52..3a13118d 100644
--- a/examples/DOM/DOMWriter.cpp
+++ b/examples/DOM/DOMWriter.cpp
@@ -27,7 +27,7 @@ int main(int argc, char* argv[])
for(int i = 1; i < argc; ++i)
{
std::string file(argv[i]);
- Arabica::SAX::InputSource is;
+ Arabica::SAX::InputSource is;
is.setSystemId(file);
if(file != "-")
diff --git a/examples/SAX/SimpleHandler.cpp b/examples/SAX/SimpleHandler.cpp
index 9809c0af..7c97ec6c 100644
--- a/examples/SAX/SimpleHandler.cpp
+++ b/examples/SAX/SimpleHandler.cpp
@@ -7,9 +7,9 @@
//////////////////////////////////////////////
// EntityResolver
-Arabica::SAX::InputSource SimpleHandler::resolveEntity(const std::string& publicId, const std::string& systemId)
+Arabica::SAX::InputSource SimpleHandler::resolveEntity(const std::string& publicId, const std::string& systemId)
{
- return Arabica::SAX::InputSource();
+ return Arabica::SAX::InputSource();
} // resolveEntity
//////////////////////////////////////////////
@@ -57,7 +57,7 @@ void SimpleHandler::endPrefixMapping(const std::string& prefix)
} // startPrefixMapping
void SimpleHandler::startElement(const std::string& namespaceURI, const std::string& localName,
- const std::string& qName, const Arabica::SAX::Attributes& atts)
+ const std::string& qName, const Arabica::SAX::Attributes& atts)
{
if(localName.length())
std::cout << "Start Element: " << namespaceURI << ":" << localName << std::endl;
@@ -93,17 +93,17 @@ void SimpleHandler::skippedEntity(const std::string& name)
/////////////////////////////////////////////////////
// ErrorHandler
-void SimpleHandler::warning(const Arabica::SAX::SAXParseException& exception)
+void SimpleHandler::warning(const Arabica::SAX::SAXParseException& exception)
{
std::cerr << "WARNING: " << exception.what() << std::endl;
} // warning
-void SimpleHandler::error(const Arabica::SAX::SAXParseException& exception)
+void SimpleHandler::error(const Arabica::SAX::SAXParseException& exception)
{
std::cerr << "ERROR : " << exception.what() << std::endl;
} // error
-void SimpleHandler::fatalError(const Arabica::SAX::SAXParseException& exception)
+void SimpleHandler::fatalError(const Arabica::SAX::SAXParseException& exception)
{
std::cerr << "FATAL : " << exception.what() << std::endl;
} // fatalError
diff --git a/examples/SAX/SimpleHandler.hpp b/examples/SAX/SimpleHandler.hpp
index 6ec48ac6..42065735 100644
--- a/examples/SAX/SimpleHandler.hpp
+++ b/examples/SAX/SimpleHandler.hpp
@@ -13,12 +13,12 @@
#include
#include
-class SimpleHandler : public Arabica::SAX::EntityResolver,
- public Arabica::SAX::DTDHandler,
- public Arabica::SAX::ContentHandler,
- public Arabica::SAX::ErrorHandler,
- public Arabica::SAX::LexicalHandler,
- public Arabica::SAX::DeclHandler
+class SimpleHandler : public Arabica::SAX::EntityResolver,
+ public Arabica::SAX::DTDHandler,
+ public Arabica::SAX::ContentHandler,
+ public Arabica::SAX::ErrorHandler,
+ public Arabica::SAX::LexicalHandler,
+ public Arabica::SAX::DeclHandler
{
public:
SimpleHandler() { }
@@ -26,7 +26,7 @@ public:
//////////////////////////////////////////////
// EntityResolver
- virtual Arabica::SAX::InputSource resolveEntity(const std::string& publicId, const std::string& systemId);
+ virtual Arabica::SAX::InputSource resolveEntity(const std::string& publicId, const std::string& systemId);
//////////////////////////////////////////////
// DTDHandler
@@ -56,9 +56,9 @@ public:
/////////////////////////////////////////////////////
// ErrorHandler
- virtual void warning(const Arabica::SAX::SAXParseException&);
- virtual void error(const Arabica::SAX::SAXParseException&);
- virtual void fatalError(const Arabica::SAX::SAXParseException& exception);
+ virtual void warning(const Arabica::SAX::SAXParseException&);
+ virtual void error(const Arabica::SAX::SAXParseException&);
+ virtual void fatalError(const Arabica::SAX::SAXParseException& exception);
///////////////////////////////////////////////////////
// LexicalHandler
diff --git a/examples/SAX/pyx.cpp b/examples/SAX/pyx.cpp
index d626f3ff..3396375b 100644
--- a/examples/SAX/pyx.cpp
+++ b/examples/SAX/pyx.cpp
@@ -19,18 +19,18 @@
#include
#include
-class SAX2PYX : public Arabica::SAX::DefaultHandler
+class SAX2PYX : public Arabica::SAX::DefaultHandler
{
public:
virtual void startElement(const std::string& namespaceURI, const std::string& localName,
- const std::string& qName, const Arabica::SAX::Attributes& atts);
+ const std::string& qName, const Arabica::SAX::Attributes& atts);
virtual void endElement(const std::string& namespaceURI, const std::string& localName,
const std::string& qName);
virtual void characters(const std::string& ch);
virtual void processingInstruction(const std::string& target, const std::string& data);
- virtual void warning(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
- virtual void error(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
+ virtual void warning(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
+ virtual void error(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
private:
std::string escape(const std::string& str) const;
@@ -55,7 +55,7 @@ int main(int argc, char* argv[])
myParser.setErrorHandler(handler);
myParser.setFeature("prohibit-dtd", false);
- Arabica::SAX::InputSource is(argv[i]);
+ Arabica::SAX::InputSource is(argv[i]);
myParser.parse(is);
} // try
catch(std::runtime_error& e)
@@ -69,7 +69,7 @@ int main(int argc, char* argv[])
void SAX2PYX::startElement(const std::string&, const std::string& localName,
- const std::string&, const Arabica::SAX::Attributes& atts)
+ const std::string&, const Arabica::SAX::Attributes& atts)
{
std::cout << '(' << localName << std::endl;
diff --git a/examples/SAX/wrapper.cpp b/examples/SAX/wrapper.cpp
index 36f3d63c..628fe172 100644
--- a/examples/SAX/wrapper.cpp
+++ b/examples/SAX/wrapper.cpp
@@ -49,12 +49,12 @@ int main(int argc, char* argv[])
if(file != "-")
{
- Arabica::SAX::InputSource is(file);
+ Arabica::SAX::InputSource is(file);
parser.parse(is);
}
else
{
- Arabica::SAX::InputSource is;
+ Arabica::SAX::InputSource is;
is.setSystemId("stdin");
is.setByteStream(std::cin);
diff --git a/examples/SAX/writer.cpp b/examples/SAX/writer.cpp
index 161d62a1..725633e2 100644
--- a/examples/SAX/writer.cpp
+++ b/examples/SAX/writer.cpp
@@ -21,7 +21,7 @@ int main(int argc, char* argv[])
{ // narrow
Arabica::SAX::FeatureNames fNames;
Arabica::SAX::XMLReader parser;
- Arabica::SAX::Writer writer(std::cout, 4);
+ Arabica::SAX::Writer writer(std::cout, 4);
Arabica::SAX::CatchErrorHandler eh;
writer.setParent(parser);
@@ -30,7 +30,7 @@ int main(int argc, char* argv[])
for(int i = 1; i < argc; ++i)
{
std::string file(argv[i]);
- Arabica::SAX::InputSource is;
+ Arabica::SAX::InputSource is;
is.setSystemId(file);
if(file != "-")
diff --git a/examples/SAX/xmlbase.cpp b/examples/SAX/xmlbase.cpp
index ab523699..51e5b1bd 100644
--- a/examples/SAX/xmlbase.cpp
+++ b/examples/SAX/xmlbase.cpp
@@ -18,19 +18,19 @@
#include
#include
-class hrefPrinter : public Arabica::SAX::DefaultHandler
+class hrefPrinter : public Arabica::SAX::DefaultHandler
{
public:
virtual void startElement(const std::string& namespaceURI, const std::string& localName,
- const std::string& qName, const Arabica::SAX::Attributes& atts);
+ const std::string& qName, const Arabica::SAX::Attributes& atts);
virtual void endElement(const std::string& namespaceURI, const std::string& localName,
const std::string& qName);
- virtual void warning(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
- virtual void error(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
+ virtual void warning(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
+ virtual void error(const Arabica::SAX::SAXParseException& e) { fatalError(e); }
private:
- Arabica::SAX::XMLBaseSupport xmlbaseTracker_;
+ Arabica::SAX::XMLBaseSupport xmlbaseTracker_;
}; // class SimpleHandler
int main(int argc, char* argv[])
@@ -51,7 +51,7 @@ int main(int argc, char* argv[])
myParser.setContentHandler(handler);
myParser.setErrorHandler(handler);
- Arabica::SAX::InputSource is(argv[i]);
+ Arabica::SAX::InputSource is(argv[i]);
myParser.parse(is);
} // try
catch(std::runtime_error& e)
@@ -65,7 +65,7 @@ int main(int argc, char* argv[])
void hrefPrinter::startElement(const std::string&, const std::string& localName,
- const std::string&, const Arabica::SAX::Attributes& atts)
+ const std::string&, const Arabica::SAX::Attributes& atts)
{
xmlbaseTracker_.startElement(atts);
diff --git a/examples/XPath/xgrep.cpp b/examples/XPath/xgrep.cpp
index 11decd2a..69cd3df7 100644
--- a/examples/XPath/xgrep.cpp
+++ b/examples/XPath/xgrep.cpp
@@ -39,7 +39,7 @@ int main(int argc, char* argv[])
for(int i = 2; i < argc; ++i)
{
std::string file(argv[i]);
- Arabica::SAX::InputSource is;
+ Arabica::SAX::InputSource is;
is.setSystemId(file);
if(file != "-")
diff --git a/examples/XSLT/mangle.cpp b/examples/XSLT/mangle.cpp
index 24131456..7adb5e09 100755
--- a/examples/XSLT/mangle.cpp
+++ b/examples/XSLT/mangle.cpp
@@ -33,7 +33,7 @@ int main(int argc, const char* argv[])
std::ostringstream errors;
try
{
- Arabica::SAX::InputSource source(argv[2]);
+ Arabica::SAX::InputSource source(argv[2]);
std::auto_ptr stylesheet = compiler.compile(source);
if(stylesheet.get() == 0)
{
@@ -64,7 +64,7 @@ int main(int argc, const char* argv[])
Arabica::DOM::Document buildDOM(const std::string& filename)
{
- Arabica::SAX::InputSource is(filename);
+ Arabica::SAX::InputSource is(filename);
Arabica::SAX2DOM::Parser parser;
parser.parse(is);
diff --git a/include/DOM/SAX2DOM/SAX2DOM.hpp b/include/DOM/SAX2DOM/SAX2DOM.hpp
index 5802b88a..3295d725 100644
--- a/include/DOM/SAX2DOM/SAX2DOM.hpp
+++ b/include/DOM/SAX2DOM/SAX2DOM.hpp
@@ -23,17 +23,17 @@ namespace SAX2DOM
template,
class SAX_parser = Arabica::SAX::XMLReader >
-class Parser : protected Arabica::SAX::basic_DefaultHandler
+class Parser : protected Arabica::SAX::DefaultHandler
{
- typedef Arabica::SAX::basic_EntityResolver EntityResolverT;
- typedef Arabica::SAX::basic_ErrorHandler ErrorHandlerT;
- typedef Arabica::SAX::basic_LexicalHandler LexicalHandlerT;
- typedef Arabica::SAX::basic_DeclHandler DeclHandlerT;
- typedef Arabica::SAX::basic_InputSource InputSourceT;
+ typedef Arabica::SAX::EntityResolver EntityResolverT;
+ typedef Arabica::SAX::ErrorHandler ErrorHandlerT;
+ typedef Arabica::SAX::LexicalHandler LexicalHandlerT;
+ typedef Arabica::SAX::DeclHandler DeclHandlerT;
+ typedef Arabica::SAX::InputSource InputSourceT;
typedef Arabica::SimpleDOM::EntityImpl EntityT;
typedef Arabica::SimpleDOM::NotationImpl NotationT;
typedef Arabica::SimpleDOM::ElementImpl ElementT;
- typedef typename Arabica::SAX::basic_ErrorHandler::SAXParseExceptionT SAXParseExceptionT;
+ typedef typename Arabica::SAX::ErrorHandler::SAXParseExceptionT SAXParseExceptionT;
public:
Parser() :
@@ -187,7 +187,7 @@ class Parser : protected Arabica::SAX::basic_DefaultHandler
} // endDocument
virtual void startElement(const stringT& namespaceURI, const stringT& localName,
- const stringT& qName, const Arabica::SAX::basic_Attributes& atts)
+ const stringT& qName, const Arabica::SAX::Attributes& atts)
{
if(currentNode_ == 0)
return;
diff --git a/include/SAX/AttributeList.hpp b/include/SAX/AttributeList.hpp
index b0186b43..08055a05 100644
--- a/include/SAX/AttributeList.hpp
+++ b/include/SAX/AttributeList.hpp
@@ -17,16 +17,16 @@ namespace SAX
* Interface for an element's attribute specifications.
*
* This is the original SAX1 interface for reporting an element's
- * attributes. Unlike the new {@link basic_Attributes Attributes}
+ * attributes. Unlike the new {@link Attributes Attributes}
* interface, it does not support Namespace-related information.
*
* When an attribute list is supplied as part of a
- * {@link basic_DocumentHandler#startElement startElement}
+ * {@link DocumentHandler#startElement startElement}
* event, the list will return valid results only during the
* scope of the event; once the event handler returns control
* to the parser, the attribute list is invalid. To save a
* persistent copy of the attribute list, use the SAX1
- * {@link basic_AttributeListImpl AttributeListImpl}
+ * {@link AttributeListImpl AttributeListImpl}
* helper class.
*
* An attribute list includes only attributes that have been
@@ -65,22 +65,22 @@ namespace SAX
*
*
* @deprecated This interface has been replaced by the SAX2
- * {@link basic_Attributes Attributes}
+ * {@link Attributes Attributes}
* interface, which includes Namespace support.
* @since SAX 1.0
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_DocumentHandler#startElement startElement
- * @see basic_AttributeListImpl
+ * @see DocumentHandler#startElement startElement
+ * @see AttributeListImpl
*/
template
-class basic_AttributeList
+class AttributeList
{
public:
typedef string_type stringT;
- virtual ~basic_AttributeList() { }
+ virtual ~AttributeList() { }
//
// Iteration methods.
@@ -186,11 +186,6 @@ public:
}; // class AttributeList
-typedef basic_AttributeList AttributeList;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_AttributeList wAttributeList;
-#endif
-
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/Attributes.hpp b/include/SAX/Attributes.hpp
index fa85a152..055590b0 100644
--- a/include/SAX/Attributes.hpp
+++ b/include/SAX/Attributes.hpp
@@ -39,7 +39,7 @@ namespace SAX
* may not be available.
*
* This interface replaces the now-deprecated SAX1 {@link
- * basic_AttributeList AttributeList} interface, which does not
+ * AttributeList AttributeList} interface, which does not
* contain Namespace support. In addition to Namespace support, it
* adds the getIndex methods (below).
*
@@ -50,15 +50,15 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_AttributesImpl
+ * @see AttributesImpl
*/
template
-class basic_Attributes
+class Attributes
{
public:
typedef string_type stringT;
- virtual ~basic_Attributes() { }
+ virtual ~Attributes() { }
//
// indexed access
@@ -227,11 +227,6 @@ public:
}; // class Attributes
-typedef basic_Attributes Attributes;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_Attributes wAttributes;
-#endif
-
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ContentHandler.hpp b/include/SAX/ContentHandler.hpp
index ac8258e0..43c7afc4 100644
--- a/include/SAX/ContentHandler.hpp
+++ b/include/SAX/ContentHandler.hpp
@@ -13,8 +13,8 @@ namespace Arabica
namespace SAX
{
-template class basic_Locator;
-template class basic_Attributes;
+template class Locator;
+template class Attributes;
/**
* Receive notification of the logical content of a document.
@@ -22,7 +22,7 @@ template class basic_Attributes;
* This is the main interface that most SAX applications
* implement: if the application needs to be informed of basic parsing
* events, it implements this interface and registers an instance with
- * the SAX parser using the {@link basic_XMLReader#setContentHandler
+ * the SAX parser using the {@link XMLReader#setContentHandler
* setContentHandler} method. The parser uses the instance to report
* basic document-related events like the start and end of elements
* and character data.
@@ -42,19 +42,19 @@ template class basic_Attributes;
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_XMLReader
- * @see basic_DTDHandler
- * @see basic_ErrorHandler
+ * @see XMLReader
+ * @see DTDHandler
+ * @see ErrorHandler
*/
template
-class basic_ContentHandler
+class ContentHandler
{
public:
typedef string_type stringT;
- typedef basic_Locator LocatorT;
- typedef basic_Attributes AttributesT;
+ typedef Locator LocatorT;
+ typedef Attributes AttributesT;
- virtual ~basic_ContentHandler() { }
+ virtual ~ContentHandler() { }
/**
* Receive an object for locating the origin of SAX document events.
@@ -79,7 +79,7 @@ public:
*
* @param locator An object that can return the location of
* any SAX document event.
- * @see basic_Locator
+ * @see Locator
*/
virtual void setDocumentLocator(const LocatorT& locator) = 0;
@@ -87,7 +87,7 @@ public:
* Receive notification of the beginning of a document.
*
* The SAX parser will invoke this method only once, before any
- * other methods in this interface or in {@link basic_DTDHandler
+ * other methods in this interface or in {@link DTDHandler
* DTDHandler} (except for {@link #setDocumentLocator
* setDocumentLocator}).
*
@@ -219,7 +219,7 @@ public:
* @exception SAXException Any SAX exception, possibly
* wrapping another exception.
* @see #endElement
- * @see basic_Attributes
+ * @see Attributes
*/
virtual void startElement(const stringT& namespaceURI, const stringT& localName,
const stringT& qName, const AttributesT& atts) = 0;
@@ -267,7 +267,7 @@ public:
* @param ch The characters from the XML document.
* @exception SAXException Any SAX exception.
* @see #ignorableWhitespace
- * @see basic_Locator
+ * @see Locator
*/
virtual void characters(const stringT& ch) = 0;
/**
@@ -332,12 +332,7 @@ public:
* @exception SAXException Any SAX exception.
*/
virtual void skippedEntity(const stringT& name) = 0;
-}; // class basic_ContentHandler
-
-typedef basic_ContentHandler ContentHandler;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_ContentHandler wContentHandler;
-#endif
+}; // class ContentHandler
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/DTDHandler.hpp b/include/SAX/DTDHandler.hpp
index dd470999..27e061c7 100644
--- a/include/SAX/DTDHandler.hpp
+++ b/include/SAX/DTDHandler.hpp
@@ -32,7 +32,7 @@ namespace SAX
* declared; however, all DTD events must be reported after the
* document handler's startDocument event, and before the first
* startElement event.
- * (If the {@link basic_LexicalHandler LexicalHandler} is
+ * (If the {@link LexicalHandler LexicalHandler} is
* used, these events must also be reported before the endDTD event.)
*
*
@@ -47,16 +47,16 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version $Id$
- * @see basic_XMLReader#setDTDHandler
+ * @see XMLReader#setDTDHandler
*/
template
-class basic_DTDHandler
+class DTDHandler
{
public:
typedef string_type stringT;
- virtual ~basic_DTDHandler() { }
+ virtual ~DTDHandler() { }
/**
@@ -70,7 +70,7 @@ public:
* When a system identifier is present, applications are responsible
* for knowing if it is used as a URL, and absolutizing it against
* the appropriate URI when appropriate.
- * That base URI is available from {@link basic_Locator#getSystemId} during
+ * That base URI is available from {@link Locator#getSystemId} during
* this callback, assuming the parser provides a Locator.
*
* At least one of publicId and systemId must be non-empty.
@@ -85,7 +85,7 @@ public:
* none was given.
* @exception SAXException Any SAX exception.
* @see #unparsedEntityDecl
- * @see basic_Attributes
+ * @see Attributes
*/
virtual void notationDecl(const stringT& name,
const stringT& publicId,
@@ -112,19 +112,14 @@ public:
* @param systemId The entity's system identifier.
* @param notationName The name of the associated notation.
* @see #notationDecl
- * @see basic_Attributes
+ * @see Attributes
*/
virtual void unparsedEntityDecl(const stringT& name,
const stringT& publicId,
const stringT& systemId,
const stringT& notationName) = 0;
-}; // class basic_DTDHandler
-
-typedef basic_DTDHandler DTDHandler;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_DTDHandler wDTDHandler;
-#endif
+}; // class DTDHandler
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/DocumentHandler.hpp b/include/SAX/DocumentHandler.hpp
index 40ea7c25..c9228b8e 100644
--- a/include/SAX/DocumentHandler.hpp
+++ b/include/SAX/DocumentHandler.hpp
@@ -10,8 +10,8 @@ namespace Arabica
namespace SAX
{
-template class basic_Locator;
-template class basic_AttributeList;
+template class Locator;
+template class AttributeList;
/**
* Receive notification of general document events.
@@ -38,19 +38,19 @@ template class basic_AttributeList;
*
* @author Jez Higgins, jez@jezuk.co.uk
* @version 0.1
- * @see basic_Parser#setDocumentHandler
- * @see basic_Locator
- * @see basic_HandlerBase
+ * @see Parser#setDocumentHandler
+ * @see Locator
+ * @see HandlerBase
*/
template
-class basic_DocumentHandler
+class DocumentHandler
{
public:
typedef string_type stringT;
- typedef basic_Locator LocatorT;
- typedef basic_AttributeList AttributeListT;
+ typedef Locator LocatorT;
+ typedef AttributeList AttributeListT;
- virtual ~basic_DocumentHandler() { }
+ virtual ~DocumentHandler() { }
virtual void setDocumentLocator(const LocatorT& locator) = 0;
@@ -67,12 +67,7 @@ public:
virtual void processingInstruction(const stringT& target,
const stringT& data) = 0;
-}; // class basic_DocumentHandler
-
-typedef basic_DocumentHandler DocumentHandler;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_DocumentHandler wDocumentHandler;
-#endif
+}; // class DocumentHandler
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/EntityResolver.hpp b/include/SAX/EntityResolver.hpp
index d83cee66..cb9f8fbd 100644
--- a/include/SAX/EntityResolver.hpp
+++ b/include/SAX/EntityResolver.hpp
@@ -21,7 +21,7 @@ namespace SAX
* If a SAX application needs to implement customized handling
* for external entities, it must implement this interface and
* register an instance with the SAX driver using the
- * {@link basic_XMLReader#setEntityResolver setEntityResolver}
+ * {@link XMLReader#setEntityResolver setEntityResolver}
* method.
*
* The XML reader will then allow the application to intercept any
@@ -66,17 +66,17 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_Parser#setEntityResolver
- * @see basic_InputSource
+ * @see Parser#setEntityResolver
+ * @see InputSource
*/
template
-class basic_EntityResolver
+class EntityResolver
{
public:
typedef string_type stringT;
- typedef basic_InputSource InputSourceT;
+ typedef InputSource InputSourceT;
- virtual ~basic_EntityResolver() { };
+ virtual ~EntityResolver() { };
/**
* Allow the application to resolve external entities.
@@ -106,16 +106,11 @@ public:
* or a default-constructed InputSource
to request that
* the parser open a regular URI connection to the system identifier.
* @exception SAXException Any SAX exception.
- * @see basic_InputSource
+ * @see InputSource
*/
virtual InputSourceT resolveEntity(const stringT& publicId, const stringT& systemId) = 0;
}; // class EntityResolver
-typedef basic_EntityResolver EntityResolver;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_EntityResolver wEntityResolver;
-#endif
-
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ErrorHandler.hpp b/include/SAX/ErrorHandler.hpp
index 1107b7bb..76fa5a0a 100644
--- a/include/SAX/ErrorHandler.hpp
+++ b/include/SAX/ErrorHandler.hpp
@@ -21,7 +21,7 @@ namespace SAX
* If a SAX application needs to implement customized error
* handling, it must implement this interface and then register an
* instance with the XML reader using the
- * {@link basic_XMLReader#setErrorHandler setErrorHandler}
+ * {@link XMLReader#setErrorHandler setErrorHandler}
* method. The parser will then report all errors and warnings
* through this interface.
*
@@ -41,17 +41,17 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_Parser#setErrorHandler
- * @see basic_SAXParseException
+ * @see Parser#setErrorHandler
+ * @see SAXParseException
*/
template
-class basic_ErrorHandler
+class ErrorHandler
{
public:
typedef string_type stringT;
- typedef basic_SAXParseException SAXParseExceptionT;
+ typedef SAXParseException SAXParseExceptionT;
- virtual ~basic_ErrorHandler() { };
+ virtual ~ErrorHandler() { };
/**
* Receive notification of a warning.
@@ -69,7 +69,7 @@ public:
*
* @param exception The warning information encapsulated in a
* SAX parse exception.
- * @see basic_SAXParseException
+ * @see SAXParseException
*/
virtual void warning(const SAXParseExceptionT& exception) = 0;
/**
@@ -93,7 +93,7 @@ public:
*
* @param exception The error information encapsulated in a
* SAX parse exception.
- * @see basic_SAXParseException
+ * @see SAXParseException
*/
virtual void error(const SAXParseExceptionT& exception) = 0;
/**
@@ -112,16 +112,11 @@ public:
*
* @param exception The error information encapsulated in a
* SAX parse exception.
- * @see basic_SAXParseException
+ * @see SAXParseException
*/
virtual void fatalError(const SAXParseExceptionT& exception) = 0;
}; // class ErrorHandler
-typedef basic_ErrorHandler ErrorHandler;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_ErrorHandler wErrorHandler;
-#endif
-
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/HandlerBase.hpp b/include/SAX/HandlerBase.hpp
index 9287e6c5..1f82099f 100644
--- a/include/SAX/HandlerBase.hpp
+++ b/include/SAX/HandlerBase.hpp
@@ -27,7 +27,7 @@ namespace SAX
* interfaces: EntityResolver, DTDHandler, DocumentHandler,
* and ErrorHandler. It is now obsolete, but is included in SAX2 to
* support legacy SAX1 applications. SAX2 applications should use
- * the {@link basic_DefaultHandler DefaultHandler}
+ * the {@link DefaultHandler DefaultHandler}
* class instead.
*
* Application writers can extend this class when they need to
@@ -38,32 +38,32 @@ namespace SAX
*
Note that the use of this class is optional.
*
* @deprecated This class works with the deprecated
- * {@link basic_DocumentHandler DocumentHandler}
+ * {@link DocumentHandler DocumentHandler}
* interface. It has been replaced by the SAX2
- * {@link basic_DefaultHandler DefaultHandler}
+ * {@link DefaultHandler DefaultHandler}
* class.
* @since SAX 1.0
* @author Jez Higgins, jez@jezuk.co.uk
* @version 1.0
- * @see basic_EntityResolver
- * @see basic_DTDHandler
- * @see basic_DocumentHandler
- * @see basic_ErrorHandler
+ * @see EntityResolver
+ * @see DTDHandler
+ * @see DocumentHandler
+ * @see ErrorHandler
*/
template
-class basic_HandlerBase : public basic_EntityResolver,
- public basic_DTDHandler,
- public basic_DocumentHandler,
- public basic_ErrorHandler
+class HandlerBase : public EntityResolver,
+ public DTDHandler,
+ public DocumentHandler,
+ public ErrorHandler
{
public:
typedef string_name stringT;
- typedef basic_Locator LocatorT;
- typedef basic_AttributeList AttributeListT;
- typedef basic_InputSource InputSourceT;
- typedef basic_ErrorHandler::SAXParseExceptionT SAXParseExceptionT;
+ typedef Locator LocatorT;
+ typedef AttributeList AttributeListT;
+ typedef InputSource InputSourceT;
+ typedef ErrorHandler::SAXParseExceptionT SAXParseExceptionT;
- virtual ~basic_HandlerBase() { }
+ virtual ~HandlerBase() { }
//////////////////////////////////////////////////////////////////////
// Default implementation of the EntityResolver interface.
@@ -83,7 +83,7 @@ public:
* document.
* @return The new input source, or an empty string to require the
* default behaviour.
- * @see basic_EntityResolver#resolveEntity
+ * @see EntityResolver#resolveEntity
*/
virtual InputSourceT resolveEntity(const stringT& publicId,
const stringT& systemId)
@@ -105,7 +105,7 @@ public:
* @param publicId The notation public identifier, or an empty string if not
* available.
* @param systemId The notation system identifier.
- * @see basic_DTDHandler#notationDecl
+ * @see DTDHandler#notationDecl
*/
virtual void notationDecl(const stringT& name,
const stringT& publicId,
@@ -123,7 +123,7 @@ public:
* available.
* @param systemId The entity system identifier.
* @param notationName The name of the associated notation.
- * @see basic_DTDHandler#unparsedEntityDecl
+ * @see DTDHandler#unparsedEntityDecl
*/
virtual void unparsedEntityDecl(const stringT& name,
const stringT& publicId,
@@ -141,8 +141,8 @@ public:
* with other document events.
*
* @param locator A locator for all SAX document events.
- * @see basic_DocumentHandler#setDocumentLocator
- * @see basic_Locator
+ * @see DocumentHandler#setDocumentLocator
+ * @see Locator
*/
virtual void setDocumentLocator(const LocatorT& locator) { }
@@ -154,7 +154,7 @@ public:
* of a document (such as allocating the root node of a tree or
* creating an output file).
*
- * @see basic_DocumentHandler#startDocument
+ * @see DocumentHandler#startDocument
*/
virtual void startDocument() { }
/**
@@ -165,7 +165,7 @@ public:
* of a document (such as finalising a tree or closing an output
* file).
*
- * @see basic_DocumentHandler#endDocument
+ * @see DocumentHandler#endDocument
*/
virtual void endDocument() { }
@@ -179,7 +179,7 @@ public:
*
* @param name The element type name.
* @param attributes The specified or defaulted attributes.
- * @see basic_DocumentHandler#startElement
+ * @see DocumentHandler#startElement
*/
virtual void startElement(const stringT& name,
const AttributeListT& attributes) { }
@@ -192,7 +192,7 @@ public:
* output to a file).
*
* @param name The element type name.
- * @see basic_DocumentHandler#endElement
+ * @see DocumentHandler#endElement
*/
virtual void endElement(const stringT& name) { }
@@ -205,7 +205,7 @@ public:
* a file).
*
* @param ch The characters.
- * @see basic_DocumentHandler#characters
+ * @see DocumentHandler#characters
*/
virtual void characters(const stringT& ch) { }
/**
@@ -217,7 +217,7 @@ public:
* it to a file).
*
* @param ch The whitespace characters.
- * @see basic_DocumentHandler#ignorableWhitespace
+ * @see DocumentHandler#ignorableWhitespace
*/
virtual void ignorableWhitespace(const stringT& ch) { }
@@ -232,7 +232,7 @@ public:
* @param target The processing instruction target.
* @param data The processing instruction data, or an empty string if
* none is supplied.
- * @see basic_DocumentHandler#processingInstruction
+ * @see DocumentHandler#processingInstruction
*/
virtual void processingInstruction(const stringT& target,
const stringT& data) { }
@@ -249,8 +249,8 @@ public:
* printing it to the console.
*
* @param e The warning information encoded as an exception.
- * @see basic_ErrorHandler#warning
- * @see basic_SAXParseException
+ * @see ErrorHandler#warning
+ * @see SAXParseException
*/
virtual void warning(const SAXParseExceptionT& e) { }
/**
@@ -262,8 +262,8 @@ public:
* printing it to the console.
*
* @param e The warning information encoded as an exception.
- * @see basic_ErrorHandler#warning
- * @see basic_SAXParseException
+ * @see ErrorHandler#warning
+ * @see SAXParseException
*/
virtual void error(const SAXParseExceptionT& e) { }
/**
@@ -278,17 +278,12 @@ public:
* the parser may no longer report parsing events.
*
* @param e The error information encoded as an exception.
- * @see basic_ErrorHandler#fatalError
- * @see basic_SAXParseException
+ * @see ErrorHandler#fatalError
+ * @see SAXParseException
*/
virtual void fatalError(const SAXParseExceptionT& e) { throw e; }
}; // class HandlerBase
-typedef basic_HandlerBase HandlerBase;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_HandlerBase wHandlerBase;
-#endif
-
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/InputSource.hpp b/include/SAX/InputSource.hpp
index 7cbff258..a4b34713 100644
--- a/include/SAX/InputSource.hpp
+++ b/include/SAX/InputSource.hpp
@@ -45,11 +45,11 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_Parser#parse
- * @see basic_EntityResolver#resolveEntity
+ * @see Parser#parse
+ * @see EntityResolver#resolveEntity
*/
template
-class basic_InputSource
+class InputSource
{
public:
typedef string_type stringT;
@@ -62,7 +62,7 @@ public:
* @see #setByteStream
* @see #setEncoding
*/
- basic_InputSource() :
+ InputSource() :
byteStream_(),
publicId_(),
systemId_(),
@@ -83,13 +83,13 @@ public:
* @see #setByteStream
* @see #setEncoding
*/
- basic_InputSource(const stringT& systemId) :
+ InputSource(const stringT& systemId) :
byteStream_(),
publicId_(),
systemId_(systemId),
encoding_()
{ }
- basic_InputSource(const basic_InputSource& rhs) :
+ InputSource(const InputSource& rhs) :
byteStream_(rhs.byteStream_),
publicId_(rhs.publicId_),
systemId_(rhs.systemId_),
@@ -104,15 +104,15 @@ public:
* character encoding.
*
* @param byteStream The raw byte stream containing the document. The
- * basic_InputSource does not assume ownership of
+ * InputSource does not assume ownership of
* this byteStream.
- * @see #basic_InputSource(std::auto_ptr)
+ * @see #InputSource(std::auto_ptr)
* @see #setPublicId
* @see #setSystemId
* @see #setEncoding
* @see #setByteStream
*/
- basic_InputSource(std::istream& byteStream) :
+ InputSource(std::istream& byteStream) :
byteStream_(byteStream),
publicId_(),
systemId_(),
@@ -129,22 +129,22 @@ public:
* character encoding.
*
* @param byteStream The raw byte stream containing the document. The
- * basic_InputSource assumes ownership of the byteStream
+ * InputSource assumes ownership of the byteStream
* and will delete it when no-longer required.
- * @see basic_InputSource(std::istream&)
+ * @see InputSource(std::istream&)
* @see #setPublicId
* @see #setSystemId
* @see #setEncoding
* @see #setByteStream
*/
- basic_InputSource(std::auto_ptr byteStream) :
+ InputSource(std::auto_ptr byteStream) :
byteStream_(byteStream),
publicId_(),
systemId_(),
encoding_()
{ }
- basic_InputSource(std::auto_ptr byteStream) :
+ InputSource(std::auto_ptr byteStream) :
byteStream_(byteStream),
publicId_(),
systemId_(),
@@ -152,9 +152,9 @@ public:
{ }
- virtual ~basic_InputSource() { }
+ virtual ~InputSource() { }
- basic_InputSource& operator=(const basic_InputSource& rhs)
+ InputSource& operator=(const InputSource& rhs)
{
byteStream_ = rhs.byteStream_;
publicId_ = rhs.publicId_;
@@ -173,8 +173,8 @@ public:
*
* @param publicId The public identifier as a string.
* @see #getPublicId
- * @see basic_Locator#getPublicId
- * @see basic_SAXParseException#getPublicId
+ * @see Locator#getPublicId
+ * @see SAXParseException#getPublicId
*/
void setPublicId(const stringT& publicId) { publicId_ = publicId; }
/**
@@ -204,8 +204,8 @@ public:
* @param systemId The system identifier as a string.
* @see #setEncoding
* @see #getSystemId
- * @see basic_Locator#getSystemId
- * @see basic_SAXParseException#getSystemId
+ * @see Locator#getSystemId
+ * @see SAXParseException#getSystemId
*/
void setSystemId(const stringT& systemId) { systemId_ = systemId; }
/**
@@ -232,7 +232,7 @@ public:
* byte stream, it should set it with the setEncoding method.
*
* @param byteStream A byte stream containing an XML document or
- * other entity. The basic_InputSource does not assume
+ * other entity. The InputSource does not assume
* ownership of byteStream.
* @see #setByteStream(std::auto_ptr) To transfer ownership of
* an std::istream to an InputSource
@@ -255,7 +255,7 @@ public:
* byte stream, it should set it with the setEncoding method.
*
* @param byteStream A byte stream containing an XML document or
- * other entity. The basic_InputSource assumes
+ * other entity. The InputSource assumes
* ownership of byteStream.
* @see #setByteStream(std::istream&)
* @see #setEncoding
@@ -328,13 +328,8 @@ private:
stringT systemId_;
stringT encoding_;
- bool operator==(const basic_InputSource&); // no implementation
-}; // class basic_InputSource
-
-typedef basic_InputSource InputSource;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_InputSource wInputSource;
-#endif
+ bool operator==(const InputSource&); // no implementation
+}; // class InputSource
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/Locator.hpp b/include/SAX/Locator.hpp
index 6c3dd75f..574d5833 100644
--- a/include/SAX/Locator.hpp
+++ b/include/SAX/Locator.hpp
@@ -19,7 +19,7 @@ namespace SAX
* If a SAX parser provides location information to the SAX
* application, it does so by implementing this interface and then
* passing an instance to the application using the content
- * handler's {@link basic_ContentHandler#setDocumentLocator
+ * handler's {@link ContentHandler#setDocumentLocator
* setDocumentLocator} method. The application can use the
* object to obtain the location of any other content handler event
* in the XML source document.
@@ -33,7 +33,7 @@ namespace SAX
* very strongly encouraged to do so. If the parser supplies a
* locator, it must do so before reporting any other document events.
* If no locator has been set by the time the application receives
- * the {@link basic_ContentHandler#startDocument startDocument}
+ * the {@link ContentHandler#startDocument startDocument}
* event, the application should assume that a locator is not
* available.
*
@@ -41,15 +41,15 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_ContentHandler#setDocumentLocator
+ * @see ContentHandler#setDocumentLocator
*/
template
-class basic_Locator
+class Locator
{
public:
typedef string_type stringT;
- virtual ~basic_Locator() { }
+ virtual ~Locator() { }
/**
* Return the public identifier for the current document event.
@@ -124,11 +124,6 @@ public:
virtual int getColumnNumber() const = 0;
}; // class Locator
-typedef basic_Locator Locator;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_Locator wLocator;
-#endif
-
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/Parser.hpp b/include/SAX/Parser.hpp
index b07fdc07..d95dd880 100644
--- a/include/SAX/Parser.hpp
+++ b/include/SAX/Parser.hpp
@@ -21,7 +21,7 @@ namespace SAX
* Basic interface for SAX (Simple API for XML) parsers.
*
* This was the main event supplier interface for SAX1; it has
- * been replaced in SAX2 by {@link basic_XMLReader XMLReader},
+ * been replaced in SAX2 by {@link XMLReader XMLReader},
* which includes Namespace support and sophisticated configurability
* and extensibility.
*
@@ -38,30 +38,30 @@ namespace SAX
* invoke the parse() methods recursively within a parse.
*
* @deprecated This interface has been replaced by the SAX2
- * {@link basic_XMLReader XMLReader}
+ * {@link XMLReader XMLReader}
* interface, which includes Namespace support.
* @since SAX 1.0
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_EntityResolver
- * @see basic_DTDHandler
- * @see basic_DocumentHandler
- * @see basic_ErrorHandler
- * @see basic_HandlerBase
- * @see basic_InputSource
+ * @see EntityResolver
+ * @see DTDHandler
+ * @see DocumentHandler
+ * @see ErrorHandler
+ * @see HandlerBase
+ * @see InputSource
*/
template
-class basic_Parser
+class Parser
{
public:
typedef string_name stringT;
- typedef basic_EntityResolver EntityResolverT;
- typedef basic_DTDHandler DTDHandlerT;
- typedef basic_DocumentHandler DocumentHandlerT;
- typedef basic_InputSource InputSourceT;
+ typedef EntityResolver EntityResolverT;
+ typedef DTDHandler DTDHandlerT;
+ typedef DocumentHandler DocumentHandlerT;
+ typedef InputSource InputSourceT;
- virtual ~basic_Parser() { }
+ virtual ~Parser() { }
// virtual void setLocale(Locale locale) throws SAXException = 0;
/**
@@ -77,8 +77,8 @@ public:
* the new resolver immediately.
*
* @param resolver The object for resolving entities.
- * @see basic_EntityResolver
- * @see basic_HandlerBase
+ * @see EntityResolver
+ * @see HandlerBase
*/
virtual void setEntityResolver(EntityResolverT& resolver) = 0;
/**
@@ -94,8 +94,8 @@ public:
* begin using the new handler immediately.
*
* @param handler The DTD handler.
- * @see basic_DTDHandler
- * @see basic_HandlerBase
+ * @see DTDHandler
+ * @see HandlerBase
*/
virtual void setDTDHandler(DTDHandlerT& handler) = 0;
/**
@@ -111,8 +111,8 @@ public:
* handler immediately.
*
* @param handler The document handler.
- * @see basic_DocumentHandler
- * @see basic_HandlerBase
+ * @see DocumentHandler
+ * @see HandlerBase
*/
virtual void setDocumentHandler(DocumentHandlerT& handler) = 0;
/**
@@ -128,9 +128,9 @@ public:
* handler immediately.
*
* @param handler The error handler.
- * @see basic_ErrorHandler
- * @see basic_SAXException
- * @see basic_HandlerBase
+ * @see ErrorHandler
+ * @see SAXException
+ * @see HandlerBase
*/
virtual void setErrorHandler(ErrorHandler& handler) = 0;
@@ -149,19 +149,14 @@ public:
*
* @param source The input source for the top-level of the
* XML document.
- * @see basic_InputSource
+ * @see InputSource
* @see #setEntityResolver
* @see #setDTDHandler
* @see #setDocumentHandler
* @see #setErrorHandler
*/
virtual void parse(InputSourceT& source) = 0;
-}; // class basic_Parser
-
-typedef basic_Parser Parser;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_Parser wParser;
-#endif
+}; // class Parser
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/SAXException.hpp b/include/SAX/SAXException.hpp
index 7d4edb54..3712d476 100644
--- a/include/SAX/SAXException.hpp
+++ b/include/SAX/SAXException.hpp
@@ -24,13 +24,13 @@ namespace SAX
*
* If the parser or application needs to include information about a
* specific location in an XML document, it should use the
- * {@link basic_SAXParseException SAXParseException} subclass.
+ * {@link SAXParseException SAXParseException} subclass.
*
* @since SAX 1.0
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_SAXParseException
+ * @see SAXParseException
*/
class SAXException : public std::runtime_error
{
diff --git a/include/SAX/SAXParseException.hpp b/include/SAX/SAXParseException.hpp
index bf83f8b0..6a9b1eb2 100644
--- a/include/SAX/SAXParseException.hpp
+++ b/include/SAX/SAXParseException.hpp
@@ -34,16 +34,16 @@ namespace SAX
* @version 2.0
* @see SAXException
* @see Locator
- * @see basic_ErrorHandler
+ * @see ErrorHandler
*/
template
-class basic_SAXParseException : public SAXException
+class SAXParseException : public SAXException
{
public:
typedef string_type stringT;
- typedef basic_Locator LocatorT;
+ typedef Locator LocatorT;
- basic_SAXParseException(const std::string& message) :
+ SAXParseException(const std::string& message) :
SAXException(message),
publicId_(),
systemId_(),
@@ -51,9 +51,9 @@ public:
columnNumber_(-1)
{
setMsg();
- } // basic_SAXParseException
+ } // SAXParseException
- basic_SAXParseException(const std::string& message,
+ SAXParseException(const std::string& message,
const LocatorT& locator) :
SAXException(message),
publicId_(locator.getPublicId()),
@@ -62,9 +62,9 @@ public:
columnNumber_(locator.getColumnNumber())
{
setMsg();
- } // basic_SAXParseException
+ } // SAXParseException
- basic_SAXParseException(const std::string& message,
+ SAXParseException(const std::string& message,
const stringT& publicId,
const stringT& systemId,
int lineNumber,
@@ -76,9 +76,9 @@ public:
columnNumber_(columnNumber)
{
setMsg();
- } // basic_SAXParseException
+ } // SAXParseException
- basic_SAXParseException(const basic_SAXParseException& rhs) :
+ SAXParseException(const SAXParseException& rhs) :
SAXException(rhs),
msg_(rhs.msg_),
publicId_(rhs.publicId_),
@@ -86,9 +86,9 @@ public:
lineNumber_(rhs.lineNumber_),
columnNumber_(rhs.columnNumber_)
{
- } // basic_SAXParseException
+ } // SAXParseException
- basic_SAXParseException& operator=(const basic_SAXParseException& rhs)
+ SAXParseException& operator=(const SAXParseException& rhs)
{
SAXException::operator=(rhs);
@@ -101,14 +101,14 @@ public:
return *this;
} // operator=
- virtual ~basic_SAXParseException() throw() { }
+ virtual ~SAXParseException() throw() { }
/**
* Get the public identifier of the entity where the exception occurred.
*
* @return A string containing the public identifier, or an empty string
* if none is available.
- * @see basic_Locator#getPublicId
+ * @see Locator#getPublicId
*/
const stringT& getPublicId() const { return publicId_; }
/**
@@ -119,7 +119,7 @@ public:
*
* @return A string containing the system identifier, or an empty string
* if none is available.
- * @see basic_Locator#getSystemId
+ * @see Locator#getSystemId
*/
const stringT& getSystemId() const { return systemId_; }
/**
@@ -127,7 +127,7 @@ public:
*
* @return An integer representing the line number, or -1
* if none is available.
- * @see basic_Locator#getLineNumber
+ * @see Locator#getLineNumber
*/
int getLineNumber() const { return lineNumber_; }
/**
@@ -137,7 +137,7 @@ public:
*
* @return An integer representing the column number, or -1
* if none is available.
- * @see basic_Locator#getColumnNumber
+ * @see Locator#getColumnNumber
*/
int getColumnNumber() const { return columnNumber_; }
@@ -162,13 +162,8 @@ private:
int lineNumber_;
int columnNumber_;
- basic_SAXParseException();
-}; // class basic_SAXParseException
-
-typedef basic_SAXParseException SAXParseException;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_SAXParseException wSAXParseException;
-#endif
+ SAXParseException();
+}; // class SAXParseException
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/XMLFilter.hpp b/include/SAX/XMLFilter.hpp
index cce32a4f..9238f5c8 100644
--- a/include/SAX/XMLFilter.hpp
+++ b/include/SAX/XMLFilter.hpp
@@ -23,25 +23,25 @@ namespace SAX
* events as they pass on to the final application.
*
* The XMLFilterImpl helper class provides a convenient base
- * for creating SAX2 filters, by passing on all {@link basic_EntityResolver
- * EntityResolver}, {@link basic_DTDHandler DTDHandler},
- * {@link basic_ContentHandler ContentHandler} and {@link ErrorHandler
+ * for creating SAX2 filters, by passing on all {@link EntityResolver
+ * EntityResolver}, {@link DTDHandler DTDHandler},
+ * {@link ContentHandler ContentHandler} and {@link ErrorHandler
* ErrorHandler} events automatically.
*
* @since SAX 2.0
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_XMLFilterImpl
+ * @see XMLFilterImpl
*/
template
-class basic_XMLFilter : public basic_XMLReader
+class XMLFilter : public XMLReaderInterface
{
public:
typedef string_type stringT;
- typedef basic_XMLReader XMLReaderT;
+ typedef XMLReaderInterface XMLReaderT;
- virtual ~basic_XMLFilter() { }
+ virtual ~XMLFilter() { }
/**
* Set the parent reader.
@@ -63,12 +63,7 @@ public:
* @return The parent filter, or 0 if none has been set.
*/
virtual XMLReaderT* getParent() const = 0;
-}; // class basic_XMLFilter
-
-typedef basic_XMLFilter XMLFilter;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_XMLFilter wXMLFilter;
-#endif
+}; // class XMLFilter
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/XMLReader.hpp b/include/SAX/XMLReader.hpp
index 31980bf4..ddefeee6 100644
--- a/include/SAX/XMLReader.hpp
+++ b/include/SAX/XMLReader.hpp
@@ -38,7 +38,7 @@ namespace SAX
* to return before reporting the next event.
*
* This interface replaces the (now deprecated) SAX 1.0 {@link
- * basic_Parser Parser} interface. The XMLReader interface
+ * Parser Parser} interface. The XMLReader interface
* contains two important enhancements over the old Parser
* interface:
*
@@ -56,24 +56,24 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_XMLFilter
- * @see basic_helpers.ParserAdapter
- * @see basic_helpers.XMLReaderAdapter
+ * @see XMLFilter
+ * @see helpers.ParserAdapter
+ * @see helpers.XMLReaderAdapter
*/
template
-class basic_XMLReader
+class XMLReaderInterface
{
public:
typedef string_type stringT;
- typedef basic_EntityResolver EntityResolverT;
- typedef basic_DTDHandler DTDHandlerT;
- typedef basic_ContentHandler ContentHandlerT;
- typedef basic_InputSource InputSourceT;
- typedef basic_ErrorHandler ErrorHandlerT;
- typedef basic_DeclHandler DeclHandlerT;
- typedef basic_LexicalHandler LexicalHandlerT;
+ typedef EntityResolver EntityResolverT;
+ typedef DTDHandler DTDHandlerT;
+ typedef ContentHandler ContentHandlerT;
+ typedef InputSource InputSourceT;
+ typedef ErrorHandler ErrorHandlerT;
+ typedef DeclHandler DeclHandlerT;
+ typedef LexicalHandler LexicalHandlerT;
- virtual ~basic_XMLReader() { }
+ virtual ~XMLReaderInterface() { }
/////////////////////////////////////////////////
// Configuration
@@ -134,7 +134,7 @@ public:
* The feature name is any fully-qualified URI. It is
* possible for an XMLReader to recognize a feature name but
* to be unable to set its value; this is especially true
- * in the case of an adapter for a SAX1 {@link basic_Parser Parser},
+ * in the case of an adapter for a SAX1 {@link Parser Parser},
* which has no way of affecting whether the underlying parser is
* validating, for example.
*
@@ -293,7 +293,7 @@ public:
* by the application before it is passed to the parser.
*
* @param systemId The system identifier (URI).
- * @see #parse(basic_InputSource&)
+ * @see #parse(InputSource&)
*/
void parse(const stringT& systemId)
{
@@ -323,7 +323,7 @@ public:
*
* @param input The input source for the top-level of the
* XML document.
- * @see basic_InputSource
+ * @see InputSource
* @see #parse(const stringT&)
* @see #setEntityResolver
* @see #setDTDHandler
@@ -363,7 +363,7 @@ public:
* The property name is any fully-qualified URI. It is
* possible for an XMLReader to recognize a property name but
* to be unable to return its state; this is especially true
- * in the case of an adapter for a SAX1 {@link basic_Parser
+ * in the case of an adapter for a SAX1 {@link Parser
* Parser}.
*
* XMLReaders are not required to recognize any specific
@@ -403,7 +403,7 @@ public:
*
The property name is any fully-qualified URI. It is
* possible for an XMLReader to recognize a property name but
* to be unable to set its value; this is especially true
- * in the case of an adapter for a SAX1 {@link basic_Parser
+ * in the case of an adapter for a SAX1 {@link Parser
* Parser}.
*
* XMLReaders are not required to recognize setting
@@ -431,7 +431,7 @@ public:
Property* prop = new Property(value);
doSetProperty(name, std::auto_ptr(prop));
} // setProperty
-}; // class basic_XMLReader
+}; // class XMLReaderInterface
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ext/Attributes2.hpp b/include/SAX/ext/Attributes2.hpp
index a8f6c3c6..48d38012 100644
--- a/include/SAX/ext/Attributes2.hpp
+++ b/include/SAX/ext/Attributes2.hpp
@@ -25,16 +25,16 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_Attributes
- * @see basic_Attributes2Impl
+ * @see Attributes
+ * @see Attributes2Impl
*/
template
-class basic_Attributes2 : public basic_Attributes
+class Attributes2 : public Attributes
{
public:
typedef string_type stringT;
- virtual ~basic_Attributes2() { }
+ virtual ~Attributes2() { }
/**
* Returns true unless the attribute value was provided by DTD defaulting.
@@ -70,12 +70,7 @@ public:
* does not identify an attribute
*/
virtual bool isSpecified(const stringT& uri, const stringT& localName) const = 0;
-}; // class basic_Attributes2
-
-typedef basic_Attributes2 Attributes2;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_Attributes2 wAttributes2;
-#endif
+}; // class Attributes2
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ext/DeclHandler.hpp b/include/SAX/ext/DeclHandler.hpp
index f05fd3c7..94cb58c0 100644
--- a/include/SAX/ext/DeclHandler.hpp
+++ b/include/SAX/ext/DeclHandler.hpp
@@ -22,15 +22,15 @@ namespace SAX
*
* Note that data-related DTD declarations (unparsed entities and
* notations) are already reported through the {@link
- * basic_DTDHandler DTDHandler} interface.
+ * DTDHandler DTDHandler} interface.
*
* If you are using the declaration handler together with a lexical
* handler, all of the events will occur between the
- * {@link basic_LexicalHandler#startDTD startDTD} and the
- * {@link basic_LexicalHandler#endDTD endDTD} events.
+ * {@link LexicalHandler#startDTD startDTD} and the
+ * {@link LexicalHandler#endDTD endDTD} events.
*
* To set the DeclHandler for an XML reader, use the
- * {@link basic_XMLReader#setProperty setProperty} method
+ * {@link XMLReader#setProperty setProperty} method
* with the propertyId "http://xml.org/sax/properties/declaration-handler".
* If the reader does not support declaration events, it will throw a
* {@link SAXNotRecognizedException SAXNotRecognizedException}
@@ -42,14 +42,14 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 1.0
- * @see basic_XMLReader
+ * @see XMLReader
*/
template
-class basic_DeclHandler
+class DeclHandler
{
public:
typedef string_type stringT;
- virtual ~basic_DeclHandler() { }
+ virtual ~DeclHandler() { }
/**
* Report an element type declaration.
@@ -106,7 +106,7 @@ public:
* entity, the name will begin with '%'.
* @param value The replacement text of the entity.
* @see #externalEntityDecl
- * @see basic_DTDHandler#unparsedEntityDecl
+ * @see DTDHandler#unparsedEntityDecl
*/
virtual void internalEntityDecl(const stringT& name, const stringT& value) = 0;
/**
@@ -121,17 +121,12 @@ public:
* an empty string if none was declared.
* @param systemId The declared system identifier of the entity.
* @see #internalEntityDecl
- * @see basic_DTDHandler#unparsedEntityDecl
+ * @see DTDHandler#unparsedEntityDecl
*/
virtual void externalEntityDecl(const stringT& name,
const stringT& publicId,
const stringT& systemId) = 0;
-}; // class basic_DeclHandler
-
-typedef basic_DeclHandler DeclHandler;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_DeclHandler wDeclHandler;
-#endif
+}; // class DeclHandler
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ext/LexicalHandler.hpp b/include/SAX/ext/LexicalHandler.hpp
index 1637a20f..b27cbcdd 100644
--- a/include/SAX/ext/LexicalHandler.hpp
+++ b/include/SAX/ext/LexicalHandler.hpp
@@ -27,7 +27,7 @@ namespace SAX
* endDocument events.
*
* To set the LexicalHandler for an XML reader, use the
- * {@link basic_XMLReader#setProperty setProperty} method
+ * {@link XMLReader#setProperty setProperty} method
* with the propertyId "http://xml.org/sax/properties/lexical-handler".
* If the reader does not support lexical events, it will throw a
* {@link SAXNotRecognizedException SAXNotRecognizedException}
@@ -39,17 +39,17 @@ namespace SAX
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 1.0
- * @see basic_XMLReader#setProperty
+ * @see XMLReader#setProperty
* @see SAXNotRecognizedException
* @see SAXNotSupportedException
*/
template
-class basic_LexicalHandler
+class LexicalHandler
{
public:
typedef string_type stringT;
- virtual ~basic_LexicalHandler() { }
+ virtual ~LexicalHandler() { }
/**
* Report the start of DTD declarations, if any.
@@ -59,8 +59,8 @@ public:
* this method will not be invoked.
*
* All declarations reported through
- * {@link basic_DTDHandler DTDHandler} or
- * {@link basic_DeclHandler DeclHandler} events must appear
+ * {@link DTDHandler DTDHandler} or
+ * {@link DeclHandler DeclHandler} events must appear
* between the startDTD and {@link #endDTD endDTD} events.
* Declarations are assumed to belong to the internal DTD subset
* unless they appear between {@link #startEntity startEntity}
@@ -74,7 +74,7 @@ public:
*
Note that the start/endDTD events will appear within
* the start/endDocument events from ContentHandler and
* before the first
- * {@link basic_ContentHandler#startElement startElement}
+ * {@link ContentHandler#startElement startElement}
* event.
*
* @param name The document type name.
@@ -116,11 +116,11 @@ public:
* When a SAX2 driver is providing these events, all other
* events must be properly nested within start/end entity
* events. There is no additional requirement that events from
- * {@link basic_DeclHandler DeclHandler} or
- * {@link basic_DTDHandler DTDHandler} be properly ordered.
+ * {@link DeclHandler DeclHandler} or
+ * {@link DTDHandler DTDHandler} be properly ordered.
*
* Note that skipped entities will be reported through the
- * {@link basic_ContentHandler#skippedEntity skippedEntity}
+ * {@link ContentHandler#skippedEntity skippedEntity}
* event, which is part of the ContentHandler interface.
*
* Because of the streaming event model that SAX uses, some
@@ -144,8 +144,8 @@ public:
* entity, the name will begin with '%', and if it is the
* external DTD subset, it will be "[dtd]".
* @see #endEntity
- * @see basic_DeclHandler#internalEntityDecl
- * @see basic_DeclHandler#externalEntityDecl
+ * @see DeclHandler#internalEntityDecl
+ * @see DeclHandler#externalEntityDecl
*/
virtual void startEntity(const stringT& name) = 0;
/**
@@ -160,7 +160,7 @@ public:
* Report the start of a CDATA section.
*
*
The contents of the CDATA section will be reported through
- * the regular {@link basic_ContentHandler#characters
+ * the regular {@link ContentHandler#characters
* characters} event; this event is intended only to report
* the boundary.
*
@@ -186,12 +186,7 @@ public:
* @param text A string holding the comment.
*/
virtual void comment(const stringT& text) = 0;
-}; // class basic_LexicalHandler
-
-typedef basic_LexicalHandler LexicalHandler;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_LexicalHandler wLexicalHandler;
-#endif
+}; // class LexicalHandler
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ext/Locator2.hpp b/include/SAX/ext/Locator2.hpp
index 8d1515f6..4512f190 100644
--- a/include/SAX/ext/Locator2.hpp
+++ b/include/SAX/ext/Locator2.hpp
@@ -26,12 +26,12 @@ namespace SAX
* @version 2.0
*/
template
-class basic_Locator2 : public basic_Locator
+class Locator2 : public Locator
{
public:
typedef string_type stringT;
- virtual ~basic_Locator2() { }
+ virtual ~Locator2() { }
/**
* Returns the version of XML used for the entity. This will normally
@@ -65,12 +65,7 @@ public:
* @return Name of the character encoding being used to interpret the entity's text.
*/
virtual stringT getEncoding() const = 0;
-}; // class basic_Locator2
-
-typedef basic_Locator2 Locator2;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_Locator2 wLocator2;
-#endif
+}; // class Locator2
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/ext/ProgressiveParser.hpp b/include/SAX/ext/ProgressiveParser.hpp
index 25fd7e47..21876e8f 100644
--- a/include/SAX/ext/ProgressiveParser.hpp
+++ b/include/SAX/ext/ProgressiveParser.hpp
@@ -40,10 +40,10 @@ namespace SAX
}; // XMLPScanToken
template
- class basic_ProgressiveParser : public basic_XMLReader
+ class ProgressiveParser : public XMLReaderInterface
{
public:
- typedef typename basic_XMLReader::InputSourceT InputSourceT;
+ typedef typename XMLReaderInterface::InputSourceT InputSourceT;
/** @name Progressive Parsing Methods */
//@{
@@ -153,12 +153,8 @@ namespace SAX
*/
virtual void parseReset(XMLPScanToken& token) = 0;
//@}
- }; // basic_ProgressiveParser
+ }; // ProgressiveParser
- typedef basic_ProgressiveParser ProgressiveParser;
-#ifndef ARABICA_NO_WCHAR_T
- typedef basic_ProgressiveParser wProgressiveParser;
-#endif
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/filter/NamespaceTracker.hpp b/include/SAX/filter/NamespaceTracker.hpp
index 6ce6d0da..941fa93a 100644
--- a/include/SAX/filter/NamespaceTracker.hpp
+++ b/include/SAX/filter/NamespaceTracker.hpp
@@ -13,23 +13,23 @@ namespace SAX
{
template >
-class NamespaceTracker : public basic_XMLFilterImpl
+class NamespaceTracker : public XMLFilterImpl
{
- typedef basic_NamespaceSupport NamespaceSupportT;
+ typedef NamespaceSupport NamespaceSupportT;
typedef typename NamespaceSupportT::stringListT stringListT;
- typedef basic_XMLFilterImpl XMLFilterT;
+ typedef XMLFilterImpl XMLFilterT;
public:
- typedef basic_XMLReader XMLReaderT;
- typedef basic_Attributes AttributesT;
+ typedef XMLReaderInterface XMLReaderT;
+ typedef Attributes AttributesT;
NamespaceTracker() :
- basic_XMLFilterImpl()
+ XMLFilterImpl()
{
} // NamespaceTracker
NamespaceTracker(XMLReaderT& parent) :
- basic_XMLFilterImpl(parent)
+ XMLFilterImpl(parent)
{
} // NamespaceTracker
diff --git a/include/SAX/filter/PYXWriter.hpp b/include/SAX/filter/PYXWriter.hpp
index 01ab274a..9f0db66f 100644
--- a/include/SAX/filter/PYXWriter.hpp
+++ b/include/SAX/filter/PYXWriter.hpp
@@ -12,7 +12,7 @@ namespace SAX
{
template
-class PYXWriter : public basic_XMLFilterImpl
+class PYXWriter : public XMLFilterImpl
{
public:
typedef string_type stringT;
@@ -20,9 +20,9 @@ class PYXWriter : public basic_XMLFilterImpl
typedef typename string_type::value_type charT;
typedef typename string_type::traits_type traitsT;
typedef std::basic_ostream ostreamT;
- typedef basic_XMLReader XMLReaderT;
- typedef basic_XMLFilterImpl XMLFilterT;
- typedef typename basic_XMLFilterImpl::AttributesT AttributesT;
+ typedef XMLReaderInterface XMLReaderT;
+ typedef XMLFilterImpl XMLFilterT;
+ typedef typename XMLFilterImpl::AttributesT AttributesT;
typedef Arabica::Unicode UnicodeT;
private:
using XMLFilterT::getParent;
diff --git a/include/SAX/filter/TextCoalescer.hpp b/include/SAX/filter/TextCoalescer.hpp
index dee71d67..374f2aa3 100644
--- a/include/SAX/filter/TextCoalescer.hpp
+++ b/include/SAX/filter/TextCoalescer.hpp
@@ -17,23 +17,23 @@ namespace SAX
This filter buffers up multiple calls to characters(...) and reports text in a single lump.
*/
template >
-class TextCoalescer : public basic_XMLFilterImpl
+class TextCoalescer : public XMLFilterImpl
{
- typedef basic_XMLFilterImpl XMLFilterT;
+ typedef XMLFilterImpl XMLFilterT;
public:
- typedef basic_XMLReader XMLReaderT;
- typedef basic_Attributes AttributesT;
+ typedef XMLReaderInterface XMLReaderT;
+ typedef Attributes AttributesT;
TextCoalescer() :
XMLFilterT()
{
- } // basic_TextCoalescer
+ } // TextCoalescer
TextCoalescer(XMLReaderT& parent) :
XMLFilterT(parent)
{
- } // basic_TextCoalescer
+ } // TextCoalescer
virtual void startElement(const string_type& namespaceURI, const string_type& localName,
const string_type& qName, const AttributesT& atts)
@@ -93,7 +93,7 @@ private:
buffer_ = string_adaptor::empty_string();
} // flush
string_type buffer_;
-}; // class basic_TextCoalescer
+}; // class TextCoalescer
} // namespace SAX
} // namespace Arabica
diff --git a/include/SAX/filter/TextOnly.hpp b/include/SAX/filter/TextOnly.hpp
index f4196d80..9f57e612 100644
--- a/include/SAX/filter/TextOnly.hpp
+++ b/include/SAX/filter/TextOnly.hpp
@@ -14,12 +14,12 @@ namespace SAX
Strips out everything except startDocument, endDocument and text
*/
template >
-class TextOnly : public basic_XMLFilterImpl
+class TextOnly : public XMLFilterImpl
{
- typedef basic_XMLFilterImpl XMLFilterT;
+ typedef XMLFilterImpl XMLFilterT;
public:
- typedef basic_XMLReader XMLReaderT;
+ typedef XMLReaderInterface XMLReaderT;
TextOnly() :
XMLFilterT(0)
diff --git a/include/SAX/filter/WhitespaceStripperFilter.hpp b/include/SAX/filter/WhitespaceStripperFilter.hpp
index a97ff718..915548d8 100644
--- a/include/SAX/filter/WhitespaceStripperFilter.hpp
+++ b/include/SAX/filter/WhitespaceStripperFilter.hpp
@@ -11,12 +11,12 @@ namespace SAX
{
template >
-class WhitespaceStripper : public SAX::basic_XMLFilterImpl
+class WhitespaceStripper : public SAX::XMLFilterImpl
{
public:
typedef string_type stringT;
- typedef SAX::basic_XMLFilterImpl baseT;
- typedef SAX::basic_XMLReader XMLReaderT;
+ typedef SAX::XMLFilterImpl baseT;
+ typedef SAX::XMLReader XMLReaderT;
WhitespaceStripper() :
baseT()
diff --git a/include/SAX/filter/Writer.hpp b/include/SAX/filter/Writer.hpp
index 290136e7..4a108a7d 100644
--- a/include/SAX/filter/Writer.hpp
+++ b/include/SAX/filter/Writer.hpp
@@ -18,29 +18,29 @@ namespace SAX
{
template
-class basic_Writer : public basic_XMLFilterImpl
+class Writer : public XMLFilterImpl
{
public:
typedef string_type stringT;
- typedef basic_Writer WriterT;
+ typedef Writer WriterT;
typedef typename string_type::value_type charT;
typedef typename string_type::traits_type traitsT;
typedef std::basic_ostream ostreamT;
- typedef basic_XMLReader XMLReaderT;
- typedef basic_XMLFilterImpl XMLFilterT;
- typedef typename basic_XMLFilterImpl::AttributesT AttributesT;
+ typedef XMLReaderInterface XMLReaderT;
+ typedef XMLFilterImpl XMLFilterT;
+ typedef typename XMLFilterImpl::AttributesT AttributesT;
typedef Arabica::Unicode UnicodeT;
typedef Arabica::XML::text_escaper text_escaperT;
typedef Arabica::XML::attribute_escaper attribute_escaperT;
private:
- typedef basic_LexicalHandler LexicalHandlerT;
- typedef basic_DeclHandler DeclHandlerT;
+ typedef LexicalHandler LexicalHandlerT;
+ typedef DeclHandler DeclHandlerT;
typedef typename XMLReaderT::InputSourceT InputSourceT;
typedef typename XMLReaderT::PropertyBase PropertyBaseT;
using XMLFilterT::getParent;
public:
- basic_Writer(ostreamT& stream, unsigned int indent = 2) :
+ Writer(ostreamT& stream, unsigned int indent = 2) :
inCDATA_(false),
inDTD_(false),
internalSubset_(true),
@@ -50,9 +50,9 @@ class basic_Writer : public basic_XMLFilterImpl
encoding_(),
lastTag_(startTag)
{
- } // basic_Writer
+ } // Writer
- basic_Writer(ostreamT& stream, XMLReaderT& parent, unsigned int indent = 2) :
+ Writer(ostreamT& stream, XMLReaderT& parent, unsigned int indent = 2) :
XMLFilterT(parent),
inCDATA_(false),
inDTD_(false),
@@ -63,9 +63,9 @@ class basic_Writer : public basic_XMLFilterImpl
encoding_(),
lastTag_(startTag)
{
- } // basic_Writer
+ } // Writer
- basic_Writer(ostreamT& stream, const stringT& encoding, unsigned int indent = 2) :
+ Writer(ostreamT& stream, const stringT& encoding, unsigned int indent = 2) :
inCDATA_(false),
inDTD_(false),
internalSubset_(true),
@@ -75,9 +75,9 @@ class basic_Writer : public basic_XMLFilterImpl
encoding_(encoding),
lastTag_(startTag)
{
- } // basic_Writer
+ } // Writer
- basic_Writer(ostreamT& stream, XMLReaderT& parent, const stringT& encoding, unsigned int indent = 2) :
+ Writer(ostreamT& stream, XMLReaderT& parent, const stringT& encoding, unsigned int indent = 2) :
XMLFilterT(parent),
inCDATA_(false),
inDTD_(false),
@@ -88,7 +88,7 @@ class basic_Writer : public basic_XMLFilterImpl
encoding_(encoding),
lastTag_(startTag)
{
- } // basic_Writer
+ } // Writer
// setEncoding
// Sets the encoding included in the XML declaration. If not set, then the encoding
@@ -149,10 +149,10 @@ class basic_Writer : public basic_XMLFilterImpl
enum { startTag, endTag, docTag } lastTag_;
const SAX::PropertyNames properties_;
-}; // class basic_Writer
+}; // class Writer
template
-void basic_Writer::startDocument()
+void Writer::startDocument()
{
*stream_ << UnicodeT::LESS_THAN_SIGN
<< UnicodeT::QUESTION_MARK
@@ -202,14 +202,14 @@ void basic_Writer::startDocument()
} // startDocument
template
-void basic_Writer::endDocument()
+void Writer::endDocument()
{
XMLFilterT::endDocument();
lastTag_ = endTag;
} // endDocument
template
-void basic_Writer::startElement(
+void Writer::startElement(
const stringT& namespaceURI, const stringT& localName,
const stringT& qName, const AttributesT& atts)
{
@@ -237,7 +237,7 @@ void basic_Writer::startElement(
} // startElement
template
-void basic_Writer::endElement(
+void Writer::endElement(
const stringT& namespaceURI, const stringT& localName,
const stringT& qName)
{
@@ -256,7 +256,7 @@ void basic_Writer::endElement(
} // endElement
template
-void basic_Writer::characters(const stringT& ch)
+void Writer::characters(const stringT& ch)
{
if(!inCDATA_)
std::for_each(ch.begin(), ch.end(), text_escaperT(*stream_));
@@ -267,7 +267,7 @@ void basic_Writer::characters(const stringT& ch)
} // characters
template
-void basic_Writer::ignorableWhitespace(const stringT& ch)
+void Writer::ignorableWhitespace(const stringT& ch)
{
*stream_ << ch;
@@ -275,7 +275,7 @@ void basic_Writer::ignorableWhitespace(const stringT& ch)
} // ignorableWhitespace
template
-void basic_Writer::processingInstruction(const stringT& target, const stringT& data)
+void Writer::processingInstruction(const stringT& target, const stringT& data)
{
if((!inDTD_) || (inDTD_ && internalSubset_))
{
@@ -294,7 +294,7 @@ void basic_Writer::processingInstruction(const stringT& target, con
} // processingInstruction
template
-void basic_Writer::skippedEntity(const stringT& name)
+void Writer::skippedEntity(const stringT& name)
{
if(!isDtd(name))
*stream_ << UnicodeT::AMPERSAND << name << UnicodeT::SEMI_COLON;
@@ -303,14 +303,14 @@ void basic_Writer::skippedEntity(const stringT& name)
} // skippedEntity
template
-void basic_Writer::doIndent()
+void Writer::doIndent()
{
for(int i = 0; i < depth_; ++i)
*stream_ << UnicodeT::SPACE;
} // doIndent
template
-bool basic_Writer::isDtd(const string_type& name)
+bool Writer::isDtd(const string_type& name)
{
return (name.length() == 5 &&
name[0] == UnicodeT::LEFT_SQUARE_BRACKET &&
@@ -321,7 +321,7 @@ bool basic_Writer::isDtd(const string_type& name)
} // isDtd
template
-void basic_Writer::startDTD(const stringT& name, const stringT& publicId, const stringT& systemId)
+void Writer::startDTD(const stringT& name, const stringT& publicId, const stringT& systemId)
{
inDTD_ = true;
depth_ += indent_;
@@ -348,7 +348,7 @@ void basic_Writer::startDTD(const stringT& name, const stringT& pub
} // startDTD
template
-void basic_Writer::endDTD()
+void Writer::endDTD()
{
*stream_ << UnicodeT::RIGHT_SQUARE_BRACKET
<< UnicodeT::GREATER_THAN_SIGN
@@ -361,7 +361,7 @@ void basic_Writer::endDTD()
} // endDTD
template
-void basic_Writer::startEntity(const stringT& name)
+void Writer::startEntity(const stringT& name)
{
if(isDtd(name))
internalSubset_ = false;
@@ -370,7 +370,7 @@ void basic_Writer::startEntity(const stringT& name)
} // startEntity
template
-void basic_Writer::endEntity(const stringT& name)
+void Writer::endEntity(const stringT& name)
{
if(isDtd(name))
internalSubset_ = true;
@@ -379,7 +379,7 @@ void basic_Writer::endEntity(const stringT& name)
} // endEntity
template
-void basic_Writer::startCDATA()
+void Writer::startCDATA()
{
inCDATA_ = true;
@@ -397,7 +397,7 @@ void basic_Writer::startCDATA()
} // startCDATA
template
-void basic_Writer::endCDATA()
+void Writer::endCDATA()
{
*stream_ << UnicodeT::RIGHT_SQUARE_BRACKET
<< UnicodeT::RIGHT_SQUARE_BRACKET
@@ -409,7 +409,7 @@ void basic_Writer::endCDATA()
} // endCDATA
template
-void basic_Writer::comment(const stringT& text)
+void Writer::comment(const stringT& text)
{
if((!inDTD_) || (inDTD_ && internalSubset_))
*stream_ << UnicodeT::LESS_THAN_SIGN
@@ -425,7 +425,7 @@ void basic_Writer::comment(const stringT& text)
} // comment
template
-void basic_Writer::notationDecl(const stringT& name, const stringT& publicId, const stringT& systemId)
+void Writer::notationDecl(const stringT& name, const stringT& publicId, const stringT& systemId)
{
if(inDTD_ && internalSubset_)
{
@@ -454,7 +454,7 @@ void basic_Writer::notationDecl(const stringT& name, const stringT&
} // notationDecl
template
-void basic_Writer::unparsedEntityDecl(const stringT& name, const stringT& publicId, const stringT& systemId, const stringT& notationName)
+void Writer::unparsedEntityDecl(const stringT& name, const stringT& publicId, const stringT& systemId, const stringT& notationName)
{
if(inDTD_ && internalSubset_)
{
@@ -479,7 +479,7 @@ void basic_Writer::unparsedEntityDecl(const stringT& name, const st
} // unparsedEntityDecl
template
-void basic_Writer::elementDecl(const stringT& name, const stringT& model)
+void Writer::elementDecl(const stringT& name, const stringT& model)
{
if(inDTD_ && internalSubset_)
{
@@ -507,7 +507,7 @@ void basic_Writer::elementDecl(const stringT& name, const stringT&
} // elementDecl
template
-void basic_Writer
diff --git a/include/SAX/ext/DefaultHandler2.hpp b/include/SAX/ext/DefaultHandler2.hpp
index 8ecc2eb8..00b54787 100644
--- a/include/SAX/ext/DefaultHandler2.hpp
+++ b/include/SAX/ext/DefaultHandler2.hpp
@@ -20,45 +20,40 @@ namespace SAX
* Default base class for SAX2 event handlers.
*
* This class extends the SAX2 base
* {@link basic_DefaultHandler} handler class to
* support the SAX2 {@link basic_LexicalHandler LexicalHandler}
* and {@link basic_DeclHandler DeclHandler} extensions.
* The added handler methods just return; subclassers may
* override on a method-by-method basis.
*
* Note: this class might yet learn that the
* ContentHandler.setDocumentLocator() call might be
- * passed a {@link basic_Locator2 Locator2} object, and
+ * passed a {@link Locator2 Locator2} object, and
* that the ContentHandler.startElement() call might be
- * passed a {@link basic_Attributes2 Attributes2} object.
+ * passed a {@link Attributes2 Attributes2} object.
*
* @since SAX 2.0
* @author Jez Higgins,
* jez@jezuk.co.uk
* @version 2.0
- * @see basic_DefaultHandler
- * @see basic_LexicalHandler
- * @see basic_DeclHandler
+ * @see DefaultHandler
+ * @see LexicalHandler
+ * @see DeclHandler
*/
template
-class basic_DefaultHandler2 : public basic_DefaultHandler
+class DefaultHandler2 : public DefaultHandler
{
public:
typedef string_type stringT;
- basic_DefaultHandler2() { }
- virtual ~basic_DefaultHandler2() { }
+ DefaultHandler2() { }
+ virtual ~DefaultHandler2() { }
private:
- basic_DefaultHandler2(const basic_DefaultHandler2&);
- basic_DefaultHandler2& operator=(const basic_DefaultHandler2&);
- bool operator==(const basic_DefaultHandler2&);
-}; // class basic_DefaultHandler
-
-typedef basic_DefaultHandler2 DefaultHandler2;
-#ifndef ARABICA_NO_WCHAR_T
-typedef basic_DefaultHandler2 wDefaultHandler2;
-#endif
+ DefaultHandler2(const DefaultHandler2&);
+ DefaultHandler2& operator=(const DefaultHandler2&);
+ bool operator==(const DefaultHandler2&);
+}; // class DefaultHandler
} // namespace SAX
} // namespace Arabica
@@ -20,45 +20,40 @@ namespace SAX
*
* This class extends the SAX2 base
- * {@link basic_DefaultHandler} handler class to
- * support the SAX2 {@link basic_LexicalHandler LexicalHandler}
- * and {@link basic_DeclHandler DeclHandler} extensions.
+ * {@link DefaultHandler} handler class to
+ * support the SAX2 {@link LexicalHandler LexicalHandler}
+ * and {@link DeclHandler DeclHandler} extensions.
* The added handler methods just return; subclassers may
* override on a method-by-method basis.